@@ -1444,6 +1444,7 @@ class OpenShift:
         github_check_run_id: Optional[int] = None,
         github_installation_id: Optional[int] = None,
         github_base_repo_url: Optional[str] = None,
+        re_run_adviser_id: Optional[str] = None
     ) -> str:
         """Schedule an adviser run."""
         if not self.backend_namespace:
@@ -1492,6 +1493,7 @@ class OpenShift:
                 "github_base_repo_url": github_base_repo_url,
                 "origin": origin,
                 "is_s2i": is_s2i,
+                "re_run_adviser_id": re_run_adviser_id
             }
         )
 
@@ -1546,6 +1548,7 @@ class OpenShift:
         github_check_run_id: Optional[int] = None,
         github_installation_id: Optional[int] = None,
         github_base_repo_url: Optional[str] = None,
+        re_run_adviser_id: Optional[str] = None,
         template: Optional[Dict[str, Any]] = None,
     ) -> str:
         """Run adviser on the provided user input."""
@@ -1580,6 +1583,7 @@ class OpenShift:
                     "github_base_repo_url": github_base_repo_url,
                     "origin": origin,
                     "is_s2i": is_s2i,
+                    "re_run_adviser_id": re_run_adviser_id
                 }
             ),
             "THOTH_ADVISER_OUTPUT": output,
